@@ -1,13 +1,16 @@
 package Database::Migrator::mysql;
 {
-  $Database::Migrator::mysql::VERSION = '0.04';
+  $Database::Migrator::mysql::VERSION = '0.05';
+}
+BEGIN {
+  $Database::Migrator::mysql::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-use Database::Migrator 0.05;
+use Database::Migrator 0.07;
 use Database::Migrator::Types qw( Str );
 use DBD::mysql;
 use DBI;
@@ -125,6 +128,8 @@ sub _run_command {
     return $stdout;
 }
 
+sub _driver_name { 'mysql' }
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
@@ -141,7 +146,7 @@ Database::Migrator::mysql - Database::Migrator implementation for MySQL
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -186,7 +191,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by MaxMind, LLC.
+This software is Copyright (c) 2013 by MaxMind, Inc..
 
 This is free software, licensed under:
 
